==> limitorderv2-sdk-0.1.48.tgz: package/src/bentoOps.ts <==
import { ethers, utils } from 'ethers'
import abi from './entities/bentoboxABI';
import { getSignatureBento, getSignatureWithProviderBentobox } from './entities/eip712'
import { getVerifyingContract } from './constants'
import { ChainId, TokenAmount } from '@sushiswap/sdk'

export async function getApprovalSignature(user: string, nonce: number, chainId: ChainId, privateKey: string) {
    let masterContract = getVerifyingContract(chainId);
    let bentoMessage = {
        warning: 'Give FULL access to funds in (and approved to) BentoBox?',
        user,
        masterContract,
        approved: true,
        nonce
    }
    return await getSignatureBento(bentoMessage, chainId, privateKey);
}

export async function batchApprovalAndDeposit(user: string, chainId: ChainId, nonce: number, token: string, amount: TokenAmount, share: TokenAmount, provider: ethers.providers.Web3Provider) {
    let bentoInterface = new utils.Interface(abi);
    let masterContract = getVerifyingContract(chainId);
    let bentoMessage = {
        warning: 'Give FULL access to funds in (and approved to) BentoBox?',
        user,
        masterContract,
        approved: true,
        nonce
    }
    const { v, r, s } = await getSignatureWithProviderBentobox(bentoMessage, chainId, provider);
    
    let approvalSignatureData = bentoInterface.encodeFunctionData('setMasterContractApproval', [user, masterContract, true, v, r, s]);
    let depositData = bentoInterface.encodeFunctionData('deposit', [token, user, masterContract, amount.raw.toString(), share.raw.toString()]);

    return [approvalSignatureData, depositData];
}

==> limitorderv2-sdk-0.1.57.tgz: package/src/bentoOps.ts <==
import { ethers, utils } from 'ethers'
import abi from './entities/bentoboxABI';
import { getSignatureBento, getSignatureWithProviderBentobox } from './entities/eip712'
import { getVerifyingContract } from './constants'
import { ChainId, CurrencyAmount, Token } from '@sushiswap/sdk'

export async function getApprovalSignature(user: string, nonce: number, chainId: ChainId, privateKey: string) {
    let masterContract = getVerifyingContract(chainId);
    let bentoMessage = {
        warning: 'Give FULL access to funds in (and approved to) BentoBox?',
        user,
        masterContract,
        approved: true,
        nonce
    }
    return await getSignatureBento(bentoMessage, chainId, privateKey);
}

export async function batchApprovalAndDeposit(user: string, chainId: ChainId, nonce: number, token: string, amount: CurrencyAmount<Token>, share: CurrencyAmount<Token>, provider: ethers.providers.Web3Provider) {
    let bentoInterface = new utils.Interface(abi);
    let masterContract = getVerifyingContract(chainId);
    let bentoMessage = {
        warning: 'Give FULL access to funds in (and approved to) BentoBox?',
        user,
        masterContract,
        approved: true,
        nonce
    }
    const { v, r, s } = await getSignatureWithProviderBentobox(bentoMessage, chainId, provider);
    
    let approvalSignatureData = bentoInterface.encodeFunctionData('setMasterContractApproval', [user, masterContract, true, v, r, s]);
    let depositData = bentoInterface.encodeFunctionData('deposit', [token, user, masterContract, amount.quotient.toString(), share.quotient.toString()]);

    return [approvalSignatureData, depositData];
}
